==> this-is-1.0.2.tar.gz: this-is-1.0.2/README.md <==
# this-is-python

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/this-is)
![PyPI - License](https://img.shields.io/pypi/l/this-is)
![PyPI](https://img.shields.io/pypi/v/this-is)
![GitHub last commit](https://img.shields.io/github/last-commit/FernandoCelmer/this-is-python) ![GitHub followers](https://img.shields.io/github/followers/FernandoCelmer?label=Fernando%20Celmer&style=social)
<br>
<br>
<img src="https://raw.githubusercontent.com/FernandoCelmer/this-is-python/master/docs/install.gif">

## How to install?
```python

pip install this-is

```

## How to use?

```python

# first command
from this_is import en_us

# second command
en_us()

The Zen of Python, by Tim Peters

Beautiful is better than ugly.
Explicit is better than implicit.
Simple is better than complex.
Complex is better than complicated.
Flat is better than nested.
Sparse is better than dense.
Readability counts.
Special cases aren't special enough to break the rules.
Although practicality beats purity.
Errors should never pass silently.
Unless explicitly silenced.
In the face of ambiguity, refuse the temptation to guess.
There should be one– and preferably only one –obvious way to do it.
Although that way may not be obvious at first unless you're Dutch.
Now is better than never.
Although never is often better than right now.
If the implementation is hard to explain, it's a bad idea.
If the implementation is easy to explain, it may be a good idea.
Namespaces are one honking great idea – let's do more of those!
```
## Languages
- pt-BR - Portuguese
- en-US - English
- es - Spanish

<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.

<!-- CONTACT -->
## Contact

Fernando Celmer- email@fernandocelmer.com

Project Link: [https://github.com/fernandocelmer/this-is-python](https://github.com/fernandocelmer/this-is-python)

==> this-is-1.0.3.tar.gz: this-is-1.0.3/README.md <==
# this-is-python

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/this-is?style=flat-square)
![PyPI - License](https://img.shields.io/pypi/l/this-is?style=flat-square)
![PyPI](https://img.shields.io/pypi/v/this-is?style=flat-square)
![PyPI - Downloads](https://img.shields.io/pypi/dm/this-is?style=flat-square)
![GitHub last commit (branch)](https://img.shields.io/github/last-commit/FernandoCelmer/this-is-python/master?style=flat-square)
![GitHub Repo stars](https://img.shields.io/github/stars/FernandoCelmer/this-is-python?style=flat-square)
![GitHub followers](https://img.shields.io/github/followers/FernandoCelmer?style=flat-square)

---

<img src="https://raw.githubusercontent.com/FernandoCelmer/this-is-python/master/docs/install.gif">

## How to install?
```python

pip install this-is

```

## How to use?

```
# First command
>>> from this_is import en_us

# Second command
>>> en_us()

The Zen of Python, by Tim Peters

Beautiful is better than ugly.
Explicit is better than implicit.
Simple is better than complex.
Complex is better than complicated.
Flat is better than nested.
Sparse is better than dense.
Readability counts.
Special cases aren't special enough to break the rules.
Although practicality beats purity.
Errors should never pass silently.
Unless explicitly silenced.
In the face of ambiguity, refuse the temptation to guess.
There should be one– and preferably only one –obvious way to do it.
Although that way may not be obvious at first unless you're Dutch.
Now is better than never.
Although never is often better than right now.
If the implementation is hard to explain, it's a bad idea.
If the implementation is easy to explain, it may be a good idea.
Namespaces are one honking great idea – let's do more of those!
```

## Languages
- pt-BR - Portuguese
- en-US - English
- es - Spanish
- fr - French

<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

## Commit Style
- ⚙️ NO-TASK
- 📝 PEP8
- 📌 ISSUE
- 🪲 BUG
- 📘 DOCS
- 📦 PyPI
- ❤️️ TEST

<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.

<!-- CONTACT -->
## Contact

Fernando Celmer- email@fernandocelmer.com

Project Link: [https://github.com/fernandocelmer/this-is-python](https://github.com/fernandocelmer/this-is-python)
